.. :changelog:

History
-------

0.1.4 (2014-06-02)
++++++++++++++++++

* Add minified JavaScript and CSS sources

0.1.3 (2014-05-28)
++++++++++++++++++

* jQuery is not automatically added by the widgets media class anymore


0.1.0 (2014-05-20)
++++++++++++++++++

* First release on PyPI.
